@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1500';
+our $VERSION = '0.1501';
 
 use Moo;
 use strictures 2;
@@ -316,7 +316,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1500
+version 0.1501
 
 =head1 SYNOPSIS
 
@@ -380,31 +380,32 @@ ignored.
 
 =head2 sentences
 
-Computed result.
+Computed result.  An array reference of every sentence!
 
 =head2 scores
 
-Computed result.
+Computed result.  An array reference of the score of each word.
 
 =head2 nrc_scores
 
-Computed result.
+Computed result.  An array reference of hash references containing the
+NRC scores for each word.
 
 =head2 positive
 
-Computed result.
+Computed result.  A module to use to L</analyze>.
 
 =head2 negative
 
-Computed result.
+Computed result.  A module to use to L</analyze>.
 
 =head2 emotion
 
-Computed result.
+Computed result.  The module to used to find the L</nrc_sentiment>.
 
 =head2 familiarity
 
-Computed result.  Hash reference of total words:
+Computed result.  Hash reference of total known and unknown words:
 
  { known => $x, unknown => $y }
 
@@ -412,7 +413,11 @@ Computed result.  Hash reference of total words:
 
 =head2 new
 
-  $opinion = Lingua::EN::Opinion->new(%arguments);
+  $opinion = Lingua::EN::Opinion->new(
+    file => $file,
+    text => $text,
+    stem => $stem,
+  );
 
 Create a new C<Lingua::EN::Opinion> object.
 
@@ -513,6 +518,8 @@ L<Statistics::Lite>
 
 L<Try::Tiny>
 
+L<WordNet::QueryData> and L<WordNet::stem> for stemming
+
 L<https://www.cs.uic.edu/~liub/FBS/sentiment-analysis.html#lexicon>
 
 L<http://saifmohammad.com/WebPages/NRC-Emotion-Lexicon.htm>
